@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2017 The Cacti Group                                 |
+ | Copyright (C) 2004-2018 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -13,7 +13,7 @@
  | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           |
  | GNU General Public License for more details.                            |
  +-------------------------------------------------------------------------+
- | Cacti: The Complete RRDTool-based Graphing Solution                     |
+ | Cacti: The Complete RRDtool-based Graphing Solution                     |
  +-------------------------------------------------------------------------+
  | This code is designed, written, and maintained by the Cacti Group. See  |
  | about.php and/or the AUTHORS file for specific developer information.   |
@@ -77,50 +77,21 @@ function automation_template_dnd() {
 	get_filter_request_var('id');
 	/* ================= Input validation ================= */
 
-	if (!isset_request_var('template_ids') || !is_array(get_nfilter_request_var('template_ids'))) exit;
+	if (isset_request_var('template_ids') && is_array(get_nfilter_request_var('template_ids'))) {
+		$aids     = get_nfilter_request_var('template_ids');
+		$sequence = 1;
 
-	/* template table contains one row defined as 'nodrag&nodrop' */
-//	unset($_REQUEST['template_ids'][0]);
+		foreach($aids as $id) {
+			$id = str_replace('line', '', $id);
+			input_validate_input_number($id);
 
-	/* delivered template ids has to be exactly the same like we have stored */
-	$old_order = array();
+			db_execute_prepared('UPDATE automation_templates
+				SET sequence = ?
+				WHERE id = ?',
+				array($sequence, $id));
 
-	$i = 1;
-	foreach(get_nfilter_request_var('template_ids') as $sequence => $id) {
-		if (empty($id)) continue;
-		$new_order[$i] = str_replace('line', '', $id);
-		$i++;
-	}
-
-	$items = db_fetch_assoc('SELECT id, sequence FROM automation_templates ORDER BY sequence');
-
-	if (sizeof($items)) {
-		$i = 1;
-		foreach($items as $item) {
-			$old_order[$i] = $item['id'];
-			$i++;
+			$sequence++;
 		}
-	} else {
-		header('Location: automation_templates.php?header=false');
-		exit;
-	}
-
-	/* perform some sanity checks */
-	if (sizeof(array_diff($new_order, $old_order)) > 0) {
-		header('Location: automation_templates.php?header=false');
-		exit;
-	}
-
-	if (sizeof(array_diff_key($new_order, $old_order))>0) {
-		header('Location: automation_templates.php?header=false');
-		exit;
-	}
-
-	foreach($new_order as $sequence => $id) {
-		input_validate_input_number($sequence);
-		input_validate_input_number($id);
-
-		db_execute_prepared('UPDATE automation_templates SET sequence = ? WHERE id = ?', array($sequence, $id));
 	}
 
 	header('Location: automation_templates.php?header=false');
@@ -170,7 +141,7 @@ function form_actions() {
 			input_validate_input_number($matches[1]);
 			/* ==================================================== */
 
-			$at_list .= '<li>' . htmlspecialchars(db_fetch_cell_prepared('SELECT ht.name FROM automation_templates AS at INNER JOIN host_template AS ht ON ht.id=at.host_template WHERE at.id = ?', array($matches[1]))) . '</li>';
+			$at_list .= '<li>' . html_escape(db_fetch_cell_prepared('SELECT ht.name FROM automation_templates AS at INNER JOIN host_template AS ht ON ht.id=at.host_template WHERE at.id = ?', array($matches[1]))) . '</li>';
 			$at_array[$i] = $matches[1];
 
 			$i++;
@@ -181,7 +152,7 @@ function form_actions() {
 
 	form_start('automation_templates.php');
 
-	html_start_box($at_actions{get_nfilter_request_var('drp_action')}, '60%', '', '3', 'center', '');
+	html_start_box($at_actions[get_nfilter_request_var('drp_action')], '60%', '', '3', 'center', '');
 
 	if (isset($at_array) && sizeof($at_array)) {
 		if (get_nfilter_request_var('drp_action') == '1') { /* delete */
@@ -192,11 +163,11 @@ function form_actions() {
 				</td>
 			</tr>\n";
 
-			$save_html = "<input type='button' value='" . __('Cancel') . "' onClick='cactiReturnTo()'>&nbsp;<input type='submit' value='" . __('Continue') . "' title='" . __('Delete Automation Template(s)') . "'>";
+			$save_html = "<input type='button' value='" . __esc('Cancel') . "' onClick='cactiReturnTo()'>&nbsp;<input type='submit' value='" . __esc('Continue') . "' title='" . __esc('Delete Automation Template(s)') . "'>";
 		}
 	} else {
 		print "<tr><td class='odd'><span class='textError'>" . __('You must select at least one Automation Template.') . "</span></td></tr>\n";
-		$save_html = "<input type='button' value='" . __('Return') . "' onClick='cactiReturnTo()'>";
+		$save_html = "<input type='button' value='" . __esc('Return') . "' onClick='cactiReturnTo()'>";
 	}
 
 	print "<tr>
@@ -286,9 +257,10 @@ function template_edit() {
 	global $availability_options;
 
 	$host_template_names = db_fetch_assoc('SELECT id, name FROM host_template');
+
 	$template_names = array();
 
-	if (sizeof($host_template_names) > 0) {
+	if (sizeof($host_template_names)) {
 		foreach ($host_template_names as $ht) {
 			$template_names[$ht['id']] = $ht['name'];
 		}
@@ -313,7 +285,7 @@ function template_edit() {
 		'sysDescr' => array(
 			'method' => 'textbox',
 			'friendly_name' => __('System Description Match'),
-			'description' => __('This is a unique string that will be matched to a devices sysDescr string to pair it to this Discovery Template.  Any Perl regular expression can be used in addition to any SQL Where expression.'),
+			'description' => __('This is a unique string that will be matched to a devices sysDescr string to pair it to this Automation Template.  Any Perl regular expression can be used in addition to any SQL Where expression.'),
 			'value' => '|arg1:sysDescr|',
 			'max_length' => '255',
 			),
@@ -346,8 +318,16 @@ function template_edit() {
 	/* ==================================================== */
 
 	if (!isempty_request_var('id')) {
-		$host_template = db_fetch_row_prepared('SELECT * FROM automation_templates WHERE id = ?', array(get_request_var('id')));
-		$header_label = __('Automation Templates [edit: %s]', htmlspecialchars($template_names[$host_template['host_template']]));
+		$host_template = db_fetch_row_prepared('SELECT *
+			FROM automation_templates
+			WHERE id = ?',
+			array(get_request_var('id')));
+
+		if (isset($template_names[$host_template['host_template']])) {
+			$header_label = __('Automation Templates [edit: %s]', html_escape($template_names[$host_template['host_template']]));
+		} else {
+			$header_label = __('Automation Templates for [Deleted Template]');
+		}
 	} else {
 		$header_label = __('Automation Templates [new]');
 		set_request_var('id', 0);
@@ -412,7 +392,7 @@ function template() {
 						<?php print __('Search');?>
 					</td>
 					<td>
-						<input id='filter' type='text' size='25' value='<?php print htmlspecialchars(get_request_var('filter'));?>'>
+						<input id='filter' type='text' size='25' value='<?php print html_escape_request_var('filter');?>'>
 					</td>
 					<td>
 						<?php print __('Templates');?>
@@ -423,7 +403,7 @@ function template() {
 							<?php
 							if (sizeof($item_rows) > 0) {
 								foreach ($item_rows as $key => $value) {
-									print "<option value='" . $key . "'"; if (get_request_var('rows') == $key) { print ' selected'; } print '>' . htmlspecialchars($value) . "</option>\n";
+									print "<option value='" . $key . "'"; if (get_request_var('rows') == $key) { print ' selected'; } print '>' . html_escape($value) . "</option>\n";
 								}
 							}
 							?>
@@ -431,8 +411,8 @@ function template() {
 					</td>
 					<td>
 						<span>
-							<input type='button' id='refresh' value='<?php print __('Go');?>' title='<?php print __('Set/Refresh Filters');?>'>
-							<input type='button' id='clear' value='<?php print __('Clear');?>' title='<?php print __('Clear Filters');?>'>
+							<input type='button' id='refresh' value='<?php print __esc('Go');?>' title='<?php print __esc('Set/Refresh Filters');?>'>
+							<input type='button' id='clear' value='<?php print __esc('Clear');?>' title='<?php print __esc('Clear Filters');?>'>
 						</span>
 					</td>
 				</tr>
@@ -441,9 +421,9 @@ function template() {
 			<script type='text/javascript'>
 			function applyFilter() {
 				strURL = 'automation_templates.php' +
-					'?filter='     + escape($('#filter').val())+
-					'&rows='       + $('#rows').val()+
-					'&has_graphs=' + $('#has_graphs').is(':checked')+
+					'?filter='     + $('#filter').val() +
+					'&rows='       + $('#rows').val() +
+					'&has_graphs=' + $('#has_graphs').is(':checked') +
 					'&header=false';
 				loadPageNoHeader(strURL);
 			}
@@ -540,13 +520,13 @@ function template() {
 			if (read_config_option('drag_and_drop') == '') {
 				$add_text = '';
 				if ($i < $total_items && $total_items > 1) {
-					$add_text .= '<a class="pic fa fa-caret-down moveArrow" href="' . htmlspecialchars('automation_templates.php?action=movedown&id=' . $dt['id']) . '" title="' . __('Move Down') . '"></a>';
+					$add_text .= '<a class="pic fa fa-caret-down moveArrow" href="' . html_escape('automation_templates.php?action=movedown&id=' . $dt['id']) . '" title="' . __esc('Move Down') . '"></a>';
 				} else {
 					$add_text .= '<span class="moveArrowNone"></span>';
 				}
 
 				if ($i > 1 && $i <= $total_items) {
-					$add_text .= '<a class="pic fa fa-caret-up moveArrow" href="' . htmlspecialchars('automation_templates.php?action=moveup&id=' . $dt['id']) . '" title="' . __('Move Up') . '"></a>';
+					$add_text .= '<a class="pic fa fa-caret-up moveArrow" href="' . html_escape('automation_templates.php?action=moveup&id=' . $dt['id']) . '" title="' . __esc('Move Up') . '"></a>';
 				} else {
 					$add_text .= '<span class="moveArrowNone"></span>';
 				}
