@@ -49,8 +49,8 @@ if (sizeof($parms)) {
 	$description   = '';
 	$ip            = '';
 	$poller_id     = $config['poller_id'];
-	$site_id       = 0;
-	$template_id   = 0;
+	$site_id       = read_config_option('default_site');
+	$template_id   = read_config_option('default_template');
 	$community     = read_config_option('snmp_community');
 	$snmp_ver      = read_config_option('snmp_version');
 	$disable       = 0;
