@@ -51,7 +51,7 @@ function imageOptionsChanged(action) {
 
 	$.getJSON(url)
 		.done(function(data) {
-			$('#image').empty().append('<img class="graphimage" src="data:image/png;base64,'+data.data+'"/>');
+			$('#image').empty().append('<img class="realtimeimage" src="data:image/png;base64,'+data.data+'"/>');
 		})
 		.fail(function(data) {
 			getPresentHTTPError(data);
@@ -70,9 +70,9 @@ function stopRealtime() {
 			return false;
 		});
 
-		$('graph_'+graph_id).zoom({ 
-			inputfieldStartTime : 'date1', 
-			inputfieldEndTime : 'date2', 
+		$('graph_'+graph_id).zoom({
+			inputfieldStartTime : 'date1',
+			inputfieldEndTime : 'date2',
 			serverTimeOffset : timeOffset
 		});
 
@@ -83,6 +83,7 @@ function stopRealtime() {
 	}
 
 	setFilters();
+	tuneFilter();
 }
 
 function setFilters() {
@@ -165,7 +166,7 @@ function realtimeGrapher() {
 			});
 		}
 	}
-	
+
 	if (inRealtime == false) {
 		stopRealtime();
 	} else {
