@@ -1,12 +1,16 @@
+// Host Autocomplete Magic
+var pageName = basename($(location).attr('pathname'));
+
 function themeReady() {
-	var pageName = basename($(location).attr('pathname'));
 	var hostTimer = false;
 	var clickTimeout = false;
 	var hostOpen = false;
 
 	$('body').css('height', $(window).height());
-	$('#navigation').css('height', ($(window).height()-80)+'px');
-	$('#navigation_right').css('height', ($(window).height()-80)+'px');
+	$('#navigation').css('height', ($(window).height()-40)+'px');
+	$('#navigation_right').css('height', ($(window).height()-40)+'px');
+
+	keepWindowSize();
 
 	// Setup the navigation menu
 	setMenuVisibility();
@@ -193,13 +197,29 @@ function setMenuVisibility() {
 	$('#navigation').hide();
 	$('li.menuitem').each(function() {
 		active = storage.get($(this).attr('id'));
-		if (active !== null && active == 'active') {
+		if (active != null) {
+			if (active == 'active') {
 			$(this).find('ul').attr('aria-hidden', 'false').attr('aria-expanded', 'true').show();
 			$(this).next('a').show();
 		}else{
 			$(this).find('ul').attr('aria-hidden', 'true').attr('aria-expanded', 'false').hide();
 			$(this).next('a').hide();
 		}
+		}
+
+		if ($(this).find('a.selected').length) {
+			$('li.menuitem').not('#'+$(this).attr('id')).each(function() {
+				$(this).find('ul').attr('aria-hidden', 'true').attr('aria-expanded', 'false').hide();
+				$(this).next('a').hide();
+				storage.set($(this).closest('.menuitem').attr('id'), 'collapsed');
+			});
+
+			if ($(this).is(':hidden')) {
+				$(this).find('ul').attr('aria-hidden', 'false').attr('aria-expanded', 'true').show();
+				$(this).next('a').show();
+				storage.set($(this).closest('.menuitem').attr('id'), 'active');
+			}
+		}
 	});
 	$('#navigation').show();
 
@@ -222,5 +242,14 @@ function setMenuVisibility() {
 				storage.set($(this).closest('.menuitem').attr('id'), 'collapsed');
 			}
 		}
+
+		$('li.menuitem').not('#'+id).each(function() {
+			text = $(this).attr('id');
+			id   = $(this).attr('id');
+
+			$(this).find('ul').attr('aria-hidden', 'true').attr('aria-expanded', 'false');
+			$(this).find('ul').slideUp( { duration: 200, easing: 'swing' } );
+			storage.set($(this).attr('id'), 'collapsed');
+		});
 	});
 }
