@@ -1,62 +1,36 @@
 // Host Autocomplete Magic
 var pageName = basename($(location).attr('pathname'));
 
-/* only perform the recalculation of elements at the final end of the windows resize event */
-var waitForFinalEvent = (function () {
-  var timers = {};
-  return function (callback, ms, uniqueId) {
-    if (!uniqueId) {
-      uniqueId = "Don't call this twice without a uniqueId";
-    }
-    if (timers[uniqueId]) {
-      clearTimeout (timers[uniqueId]);
-    }
-    timers[uniqueId] = setTimeout(callback, ms);
-  };
-})();
-
-function keepWindowSize() {
+function myKeepWindowSize() {
 	$(window).resize(function (event) {
 		waitForFinalEvent(function(){
 			/* close open dropdown menues first off */
 			$('.dropdownMenu > ul').hide();
-			heightPage = $(window).height();
-			heightPageHead = $('#cactiPageHead').outerHeight();
-			heightPageBottom = $('#cactiPageBottom').outerHeight();
-			heightPageContent = heightPage -heightPageHead -heightPageBottom +1;
-
-			$('body').css('height', heightPage);
-			$('#cactiContent').css('height', heightPageContent);
-
-			$('.cactiTreeNavigationArea').css('height', heightPageContent);
-			width = parseInt($('#searcher').width())+65;
-			$('.cactiTreeNavigationArea').css('width', width+'px');
-			$('.cactiTreeNavigationArea > div').css('padding-top', '5px');
 
 			/* check visibility of all tabs */
 			$('#submenu-ellipsis').empty();
 			$('.maintabs nav ul li a').each(function() {
 				id = $(this).attr('id');
-				if( $(this).offset().top !== 0 ) {
-					if( $('#' + id + '-ellipsis').length == 0 ) {
+				if ( $(this).offset().top !== 0 ) {
+					if ( $('#' + id + '-ellipsis').length == 0 ) {
 						var str = $(this).parent().html();
 						var str2 = str.replace( id , id + '-ellipsis');
 						$('#submenu-ellipsis').prepend('<li>' + str2 + '</li>');
 						$('#'+ id + '-ellipsis').css('visibility','');
 						$(this).css('visibility', 'hidden');
 					}
-				}else {
+				} else {
 					$('#' + id + '-ellipsis').parent().remove();
 					$(this).css('visibility', 'visible');
 				}
 			});
 
-			if($("#submenu-ellipsis li").length == 0) {
-				$(".ellipsis").hide(0);
-			}else {
-				$(".ellipsis").show(0);
+			if ($('#submenu-ellipsis li').length == 0) {
+				$('.ellipsis').hide(0);
+			} else {
+				$('.ellipsis').show(0);
 			}
-		}, 300, "resize-content");
+		}, 300, 'resize-content');
 	});
 }
 
@@ -66,7 +40,7 @@ function themeReady() {
 	var clickTimeout = false;
 	var hostOpen = false;
 
-	keepWindowSize();
+	myKeepWindowSize();
 
 	// Setup the navigation menu
 	setMenuVisibility();
@@ -120,7 +94,7 @@ function themeReady() {
 	+'</div>').appendTo('body');
 
 	/* Hey - No footer available ? */
-	if($('#cactiPageBottom').length == 0) {
+	if ($('#cactiPageBottom').length == 0) {
 		$('<div id="cactiPageBottom" class="cactiPageBottom"><span class="cactiVersion">Version '+ cactiVersion +'</span><a class="bottom_scroll_up action-icon-user" href="#"><i class="fa fa-arrow-circle-up"></i></a></div>').insertAfter('#cactiContent');
 	}
 	/* Console? Nope! */
@@ -130,7 +104,7 @@ function themeReady() {
 		id = $(this).attr('id');
 		if ( id == 'maintab-anchor-console') {
 			$(this).html("<i class='fa fa-sun-o'/>");
-		}else if ( id == 'maintab-anchor-graphs' && $(this).parent().hasClass('maintabs-has-submenu') == 0 ) {
+		} else if ( id == 'maintab-anchor-graphs' && $(this).parent().hasClass('maintabs-has-submenu') == 0 ) {
 			submenu_counter++;
 			$(this).parent().addClass('maintabs-has-submenu');
 			$('<li class="maintabs-submenu"><a class="submenu-' + submenu_counter + '" href="#"><i class="fa fa-caret-down"></i></a></li>').insertAfter( $(this) );
@@ -141,7 +115,7 @@ function themeReady() {
 					+'<li><a href="'+urlPath+'graph_view.php?action=preview"><span>'+previewView+'</span></a></li>'
 				+'</ul>'
 			+'</div>').appendTo('body');
-		}else {
+		} else {
 			/* plugin stuff here ? */
 		}
 	});
@@ -165,8 +139,6 @@ function themeReady() {
 		+'</div>').appendTo('body');
 	}
 
-
-
 	ajaxAnchors();
 
 	/* User Menu */
@@ -177,10 +149,10 @@ function themeReady() {
 	$('.action-icon-user').unbind().click(function(event) {
 		event.preventDefault();
 
-		if( $('.menuoptions').is(':visible') === false ) {
+		if ( $('.menuoptions').is(':visible') === false ) {
 			$('.submenuoptions').stop().slideUp(120);
 			$('.menuoptions').stop().slideDown(120);
-		}else {
+		} else {
 			$('.menuoptions').stop().slideUp(120);
 		}
 		return false;
@@ -197,20 +169,20 @@ function themeReady() {
 		submenu_index = $(this).children('a:first').attr('class');
 		submenu = $('#'+submenu_index);
 
-		if( submenu.is(':visible') === false ) {
+		if ( submenu.is(':visible') === false ) {
 			/* close other drop down menus first */
 			$('.submenuoptions').stop().slideUp(120);
 			$('.menuoptions').stop().slideUp(120);
 			/* re-position */
 			position = $(this).parent('.maintabs-has-submenu').position();
-			if(!position) {
+			if (!position) {
 				position = $(this).position();
 				submenu.css({'left':position.left - parseInt(submenu.outerWidth()) + parseInt($(this).outerWidth()) }).slideDown(120);
-			}else {
+			} else {
 				/* move dd to the left */
 				submenu.css({'left':position.left}).slideDown(120);
 			}
-		}else {
+		} else {
 			submenu.slideUp(120);
 		}
 
@@ -222,12 +194,11 @@ function themeReady() {
 	}).mouseleave(function(data) {
 		if ($('.submenuoptions').is(':visible')) {
 			userMenuTimer = setTimeout(function() {$('.submenuoptions').stop().slideUp(120);}, 1000);
-		}else{
+		} else {
 			clearTimeout(userMenuOpenTimer);
 		}
 	});
 
-
 	/* Highlight sortable table columns */
 	$('.tableHeader th').has('i.fa-unsorted').removeClass('tableHeaderColumnHover tableHeaderColumnSelected');
 	$('.tableHeader th').has('i.fa-sort-asc').addClass('tableHeaderColumnSelected');
@@ -283,7 +254,7 @@ function themeReady() {
 				$('#'+id+'-button').css('min-width', minWidth+'px').css('max-width', '400px').css('width','');
 				$('#'+id+'-menu').css('max-height', '250px');
 			});
-		}else{
+		} else {
 			$(this).addClass('ui-state-default ui-corner-all');
 		}
 	});
@@ -297,9 +268,9 @@ function themeReady() {
 			callBack = $('#call_back').val();
 			if (callBack != 'undefined') {
 				eval(callBack);
-			}else if (typeof applyGraphFilter === 'function') {
+			} else if (typeof applyGraphFilter === 'function') {
 				applyGraphFilter();
-			}else{
+			} else {
 				applyFilter();
 			}
 		}
@@ -309,17 +280,14 @@ function themeReady() {
 		if (!hostOpen) {
 			$('#host').autocomplete('option', 'minLength', 0).autocomplete('search', '');
 			hostOpen = true;
-		}else{
+		} else {
 			$('#host').autocomplete('close');
 			hostOpen = false;
 		}
 	});
 
-/* End clean up */
-
-
 	/* Notification Handler */
-	if( $("#message").length ) {
+	if ($("#message").length) {
 	//	alert($('#message_container').html());
 	}
 
@@ -374,7 +342,7 @@ function setMenuVisibility() {
 			if (active == 'active') {
 				$(this).find('ul').attr('aria-hidden', 'false').attr('aria-expanded', 'true').show();
 				$(this).next('a').show();
-			}else{
+			} else {
 				$(this).find('ul').attr('aria-hidden', 'true').attr('aria-expanded', 'false').hide();
 				$(this).next('a').hide();
 			}
@@ -411,7 +379,7 @@ function setMenuVisibility() {
 			$(this).next().slideToggle( { duration: 200, easing: 'swing' } );
 			if ($(this).next().is(':visible')) {
 				storage.set($(this).closest('.menuitem').attr('id'), 'active');
-			}else{
+			} else {
 				storage.set($(this).closest('.menuitem').attr('id'), 'collapsed');
 			}
 		}
