@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2017 The Cacti Group                                 |
+ | Copyright (C) 2004-2018 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -13,7 +13,7 @@
  | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           |
  | GNU General Public License for more details.                            |
  +-------------------------------------------------------------------------+
- | Cacti: The Complete RRDTool-based Graphing Solution                     |
+ | Cacti: The Complete RRDtool-based Graphing Solution                     |
  +-------------------------------------------------------------------------+
  | This code is designed, written, and maintained by the Cacti Group. See  |
  | about.php and/or the AUTHORS file for specific developer information.   |
@@ -213,7 +213,7 @@ function getGraphTemplatesByHostTemplate($host_template_id) {
 	return $graph_templates;
 }
 
-function displayQueryTypes($types, $quietMode = FALSE) {
+function displayQueryTypes($types, $quietMode = false) {
 	if (!$quietMode) {
 		echo "Known SNMP Query Types: (id, name)\n";
 	}
@@ -227,7 +227,7 @@ function displayQueryTypes($types, $quietMode = FALSE) {
 	}
 }
 
-function displayHostTemplates($host_templates, $quietMode = FALSE) {
+function displayHostTemplates($host_templates, $quietMode = false) {
 	if (!$quietMode) {
 		echo "Valid Device Templates: (id, name)\n";
 	}
@@ -243,7 +243,7 @@ function displayHostTemplates($host_templates, $quietMode = FALSE) {
 	}
 }
 
-function displayCommunities($quietMode = FALSE) {
+function displayCommunities($quietMode = false) {
 	if (!$quietMode) {
 		echo "Known communities are: (community)\n";
 	}
@@ -261,7 +261,7 @@ function displayCommunities($quietMode = FALSE) {
 	}
 }
 
-function displaySNMPFields($fields, $hostId, $quietMode = FALSE) {
+function displaySNMPFields($fields, $hostId, $quietMode = false) {
 	if (!$quietMode) {
 		echo "Known SNMP Fields for host-id $hostId: (name)\n";
 	}
@@ -275,7 +275,7 @@ function displaySNMPFields($fields, $hostId, $quietMode = FALSE) {
 	}
 }
 
-function displaySNMPValues($values, $hostId, $field, $quietMode = FALSE) {
+function displaySNMPValues($values, $hostId, $field, $quietMode = false) {
 	if (!$quietMode) {
 		echo "Known values for $field for host $hostId: (name)\n";
 	}
@@ -289,7 +289,7 @@ function displaySNMPValues($values, $hostId, $field, $quietMode = FALSE) {
 	}
 }
 
-function displaySNMPQueries($queries, $quietMode = FALSE) {
+function displaySNMPQueries($queries, $quietMode = false) {
 	if (!$quietMode) {
 		echo "Known SNMP Queries:(id, name)\n";
 	}
@@ -303,7 +303,7 @@ function displaySNMPQueries($queries, $quietMode = FALSE) {
 	}
 }
 
-function displayInputFields($input_fields, $quietMode = FALSE) {
+function displayInputFields($input_fields, $quietMode = false) {
 	if (!$quietMode) {
 		echo "Known Input Fields:(name, default, description)\n";
 	}
@@ -319,7 +319,7 @@ function displayInputFields($input_fields, $quietMode = FALSE) {
 	}
 }
 
-function displayGraphTemplates($templates, $quietMode = FALSE) {
+function displayGraphTemplates($templates, $quietMode = false) {
 	if (!$quietMode) {
 		echo "Known Graph Templates:(id, name)\n";
 	}
@@ -333,7 +333,7 @@ function displayGraphTemplates($templates, $quietMode = FALSE) {
 	}
 }
 
-function displayHosts($hosts, $quietMode = FALSE) {
+function displayHosts($hosts, $quietMode = false) {
 	if (!$quietMode) {
 		echo "Known Devices: (id, hostname, template, description)\n";
 	}
@@ -349,7 +349,7 @@ function displayHosts($hosts, $quietMode = FALSE) {
 	}
 }
 
-function displayTrees($quietMode = FALSE) {
+function displayTrees($quietMode = false) {
 	global $tree_sort_types;
 
 	if (!$quietMode) {
@@ -371,7 +371,7 @@ function displayTrees($quietMode = FALSE) {
 	}
 }
 
-function displayTreeNodes($tree_id, $nodeType = '', $parentNode = 0, $quietMode = FALSE) {
+function displayTreeNodes($tree_id, $nodeType = '', $parentNode = 0, $quietMode = false) {
 	global $tree_sort_types, $tree_item_types, $host_group_types;
 
 	if ($parentNode == 0) {
@@ -464,7 +464,7 @@ function displayTreeNodes($tree_id, $nodeType = '', $parentNode = 0, $quietMode
 	}
 }
 
-function displayRRAs($quietMode = FALSE) {
+function displayRRAs($quietMode = false) {
 	if (!$quietMode) {
 		echo "Known RRAs:\nid\tsteps\trows\tname\n";
 	}
@@ -485,7 +485,7 @@ function displayRRAs($quietMode = FALSE) {
 	}
 }
 
-function displayHostGraphs($host_id, $quietMode = FALSE) {
+function displayHostGraphs($host_id, $quietMode = false) {
 
 	if (!$quietMode) {
 		echo "Known Device Graphs: (id, name, template)\n";
@@ -515,7 +515,7 @@ function displayHostGraphs($host_id, $quietMode = FALSE) {
 	}
 }
 
-function displayUsers($quietMode = FALSE) {
+function displayUsers($quietMode = false) {
 	if (!$quietMode) {
 		echo "Known Users:\nid\tusername\tfull_name\n";
 	}
