@@ -197,7 +197,7 @@ if (!$master && $thread == 0) {
 		array($network_id, $poller_id));
 
 	if ($status != 'on' && !$force) {
-		cacti_log("ERROR: The Network ID: $network_id is disabled.  You must use the 'force' option to force it's execution.", true, 'AUTOM8');
+		cacti_log("WARNING: The Network ID: $network_id is disabled.  You must use the 'force' option to force it's execution.", true, 'AUTOM8');
 		exit;
 	}
 }
@@ -670,7 +670,7 @@ function discoverDevices($network_id, $thread) {
 							// if the devices template is not discovered, add to found table
 							if ($host_id == 0) {
 								db_execute('REPLACE INTO automation_devices
-									(network_id, hostname, ip, community, snmp_version, snmp_port, snmp_username, snmp_password, snmp_auth_protocol, snmp_priv_passphrase, snmp_priv_protocol, snmp_context, sysName, sysLocation, sysContact, sysDescr, sysUptime, os, snmp, up, time) VALUES ('
+									(network_id, hostname, ip, snmp_community, snmp_version, snmp_port, snmp_username, snmp_password, snmp_auth_protocol, snmp_priv_passphrase, snmp_priv_protocol, snmp_context, sysName, sysLocation, sysContact, sysDescr, sysUptime, os, snmp, up, time) VALUES ('
 									. $network_id                              . ', '
 									. db_qstr($device['dnsname'])              . ', '
 									. db_qstr($device['ip_address'])           . ', '
@@ -696,7 +696,7 @@ function discoverDevices($network_id, $thread) {
 						}
 					}else if ($result) {
 						db_execute('REPLACE INTO automation_devices
-							(network_id, hostname, ip, community, snmp_version, snmp_port, snmp_username, snmp_password, snmp_auth_protocol, snmp_priv_passphrase, snmp_priv_protocol, snmp_context, sysName, sysLocation, sysContact, sysDescr, sysUptime, os, snmp, up, time) VALUES ('
+							(network_id, hostname, ip, snmp_community, snmp_version, snmp_port, snmp_username, snmp_password, snmp_auth_protocol, snmp_priv_passphrase, snmp_priv_protocol, snmp_context, sysName, sysLocation, sysContact, sysDescr, sysUptime, os, snmp, up, time) VALUES ('
 							. $network_id                              . ', '
 							. db_qstr($device['dnsname'])              . ', '
 							. db_qstr($device['ip_address'])           . ', '
