@@ -2,7 +2,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2017 The Cacti Group                                 |
+ | Copyright (C) 2004-2018 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -14,7 +14,7 @@
  | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           |
  | GNU General Public License for more details.                            |
  +-------------------------------------------------------------------------+
- | Cacti: The Complete RRDTool-based Graphing Solution                     |
+ | Cacti: The Complete RRDtool-based Graphing Solution                     |
  +-------------------------------------------------------------------------+
  | This code is designed, written, and maintained by the Cacti Group. See  |
  | about.php and/or the AUTHORS file for specific developer information.   |
@@ -31,7 +31,7 @@ $no_http_headers = true;
 
 /*  display_version - displays version information */
 function display_version() {
-    $version = db_fetch_cell('SELECT cacti FROM version');
+	$version = get_cacti_version();
 	echo "Cacti Reporting Poller, Version $version, " . COPYRIGHT_YEARS . "\n";
 }
 
@@ -85,8 +85,8 @@ global $current_user;
 $parms = $_SERVER['argv'];
 array_shift($parms);
 
-$debug          = FALSE;
-$force          = FALSE;
+$debug = false;
+$force = false;
 
 if (sizeof($parms)) {
 	foreach($parms as $parameter) {
@@ -100,11 +100,11 @@ if (sizeof($parms)) {
 		switch ($arg) {
 			case '-f':
 			case '--force':
-				$force = TRUE;
+				$force = true;
 				break;
 			case '-d':
 			case '--debug':
-				$debug = TRUE;
+				$debug = true;
 				break;
 			case '--version':
 			case '-V':
